@@ -181,5 +181,5 @@ madcat_collector = run_madcat(Data(df=df, target_column='target'),
                               is_pre_model=True,
                               is_model_training=False,
                               model_run=ModelRun(n_models=3),
-                              is_post_model=True, is_model_weaknesses=True
+                              is_post_model=False, is_model_weaknesses=False
                               )
